#!/usr/bin/env python
# encoding: utf-8
# Copyright (C) 2012 Stefanos Kariotidis <stef@iccode.net>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import gzip
import cStringIO
import urllib2
import json


class StackSearch(object):
	"""Searches Stackexchange sites for answers"""

	def __init__(self):
		self.question = ""
		self.site = ""

	def _parse_arguments(self, arguments):
		"""parses the arguments and checks for trivial errors"""

		if len(arguments) > 1:

			arguments = arguments[:-1]
			args = arguments.split(" ")
			print "ARGUMENTS: %s" % arguments
			for arg in args:
				if arg.startswith("~~"):
					arg = arg.lstrip("~~")
					self.site = arg
				else:
					self.question = self.question + " %s" %arg

	def _stack_query(self, question="unity lenses", site="askubuntu"):
		"""makes the url request and reads json from server's response"""

		stackexchange = "https://api.stackexchange.com/"
		query_begin = "2.0/search?order=desc&sort=creation&intitle="
		query_end = "&site="
		question = question.replace(" ", "%%20")
		url_string = stackexchange + query_begin + question + query_end + site
		try:
			print "Searching question titles containing %s at %s" % (question, site)
			print "Search string %s\n" % (url_string)
			connection = urllib2.urlopen(url_string)
			response = connection.read()
			connection.close()
			results = json.load(gzip.GzipFile(fileobj=cStringIO.StringIO(response)))
			return results
		except (IOError, KeyError, urllib2.URLError, urllib2.HTTPError, ValueError, TypeError) as e:
			print "Cannot access %s" % site
			print e
			return []

	def do_search(self, arguments):
		"""Runs the search"""
		
		self._parse_arguments(arguments)
		results = {}
		response = self._stack_query(self.question, self.site)
		#hold only answered questions and their links
		if "items" in response:
			for item in response["items"]:
				if item["is_answered"]:
					results[item["title"]] = item["link"]
		return results
		

def main():
	pass


if __name__ == '__main__':
	main()